aboutsummaryrefslogtreecommitdiffstats
path: root/components/script_traits/lib.rs
diff options
context:
space:
mode:
authorConnor Brewster <connor.brewster@eagles.oc.edu>2018-04-20 22:44:59 -0500
committerConnor Brewster <connor.brewster@eagles.oc.edu>2018-04-24 15:13:11 -0500
commite7ef9cfb303598e582f0f589da855bdd33c1dd08 (patch)
tree1c646a8c69c32f9045b81b0b7ab46270a7acbab3 /components/script_traits/lib.rs
parent05fe8fa08d507836ce5659ff56f83022a90b241a (diff)
downloadservo-e7ef9cfb303598e582f0f589da855bdd33c1dd08.tar.gz
servo-e7ef9cfb303598e582f0f589da855bdd33c1dd08.zip
Make session history aware of URLs
Diffstat (limited to 'components/script_traits/lib.rs')
-rw-r--r--components/script_traits/lib.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/components/script_traits/lib.rs b/components/script_traits/lib.rs
index 272cfe3cedb..98cf57116a7 100644
--- a/components/script_traits/lib.rs
+++ b/components/script_traits/lib.rs
@@ -289,8 +289,8 @@ pub enum ConstellationControlMsg {
/// Updates the current pipeline ID of a given iframe.
/// First PipelineId is for the parent, second is the new PipelineId for the frame.
UpdatePipelineId(PipelineId, BrowsingContextId, PipelineId, UpdatePipelineIdReason),
- /// Updates the history state of a given pipeline.
- UpdateHistoryStateId(PipelineId, Option<HistoryStateId>),
+ /// Updates the history state and url of a given pipeline.
+ UpdateHistoryState(PipelineId, Option<HistoryStateId>, ServoUrl),
/// Removes inaccesible history states.
RemoveHistoryStates(PipelineId, Vec<HistoryStateId>),
/// Set an iframe to be focused. Used when an element in an iframe gains focus.
@@ -347,7 +347,7 @@ impl fmt::Debug for ConstellationControlMsg {
Navigate(..) => "Navigate",
PostMessage(..) => "PostMessage",
UpdatePipelineId(..) => "UpdatePipelineId",
- UpdateHistoryStateId(..) => "UpdateHistoryStateId",
+ UpdateHistoryState(..) => "UpdateHistoryState",
RemoveHistoryStates(..) => "RemoveHistoryStates",
FocusIFrame(..) => "FocusIFrame",
WebDriverScriptCommand(..) => "WebDriverScriptCommand",